==> jc-1.4.0.tar.gz: java/security/AllPermission.h <==
// public final class java.security.AllPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b53f70fa48574edf java_security_AllPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_security_AllPermission_H_
#define _JC_java_security_AllPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_security_AllPermission$sub_refs	_jc_java_security_AllPermission$sub_refs;
typedef struct _jc_java_security_AllPermission$sub_nonrefs	_jc_java_security_AllPermission$sub_nonrefs;
typedef struct _jc_java_security_AllPermission$refs	_jc_java_security_AllPermission$refs;
typedef struct _jc_java_security_AllPermission$nonrefs	_jc_java_security_AllPermission$nonrefs;
typedef struct _jc_java_security_AllPermission$object	_jc_java_security_AllPermission$object;

typedef struct _jc_java_security_AllPermission$fields_struct	_jc_java_security_AllPermission$fields_struct;
typedef const struct _jc_java_security_AllPermission$vmethods	_jc_java_security_AllPermission$vmethods;
typedef const struct _jc_java_security_AllPermission$vtable	_jc_java_security_AllPermission$vtable;
typedef const struct _jc_java_security_AllPermission$vtype	_jc_java_security_AllPermission$vtype;

// Class fields structure
struct _jc_java_security_AllPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_AllPermission$fields_struct _jc_java_security_AllPermission$class_fields;

// Constructors
extern void _jc_java_security_AllPermission$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AllPermission$object *);
extern void _jc_java_security_AllPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java_security_AllPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_AllPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_security_AllPermission$object *);
extern jint _jc_java_security_AllPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_AllPermission$object *);
extern jboolean _jc_java_security_AllPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_AllPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_security_AllPermission$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_AllPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_AllPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_security_AllPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_AllPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_AllPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_java_security_AllPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_security_AllPermission$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_AllPermission$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_security_Permission$object *);
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_security_AllPermission$object *);
};

// Vtable
struct _jc_java_security_AllPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_AllPermission$vmethods	java_security_AllPermission;
};

// Vtype
struct _jc_java_security_AllPermission$vtype {
	_jc_type			type;
	_jc_java_security_AllPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AllPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AllPermission$refs {
    _jc_java_security_AllPermission$sub_refs	java_security_AllPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AllPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AllPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_AllPermission$sub_nonrefs	java_security_AllPermission;
};

// Object instance structure
struct _jc_java_security_AllPermission$object {
	_jc_java_security_AllPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AllPermission$vtype	*vtype;
	_jc_java_security_AllPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AllPermission$vtype _jc_java_security_AllPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AllPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AllPermission$class_object;

#endif	/* _JC_java_security_AllPermission_H_ */

==> jc-1.4.6.tar.gz: java/security/AllPermission.h <==
// public final class java.security.AllPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b53f70fa48574edf java_security_AllPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_security_AllPermission_H_
#define _JC_java_security_AllPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_security_AllPermission$sub_refs	_jc_java_security_AllPermission$sub_refs;
typedef struct _jc_java_security_AllPermission$sub_nonrefs	_jc_java_security_AllPermission$sub_nonrefs;
typedef struct _jc_java_security_AllPermission$refs	_jc_java_security_AllPermission$refs;
typedef struct _jc_java_security_AllPermission$nonrefs	_jc_java_security_AllPermission$nonrefs;
typedef struct _jc_java_security_AllPermission$object	_jc_java_security_AllPermission$object;

typedef struct _jc_java_security_AllPermission$fields_struct	_jc_java_security_AllPermission$fields_struct;
typedef const struct _jc_java_security_AllPermission$vmethods	_jc_java_security_AllPermission$vmethods;
typedef const struct _jc_java_security_AllPermission$vtable	_jc_java_security_AllPermission$vtable;
typedef const struct _jc_java_security_AllPermission$vtype	_jc_java_security_AllPermission$vtype;

// Class fields structure
struct _jc_java_security_AllPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_AllPermission$fields_struct _jc_java_security_AllPermission$class_fields;

// Constructors
extern void _jc_java_security_AllPermission$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_AllPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_security_AllPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_AllPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_AllPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_AllPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_AllPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_AllPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_AllPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_security_AllPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_AllPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_AllPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_java_security_AllPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_AllPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_security_AllPermission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_AllPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_AllPermission$vmethods	java_security_AllPermission;
};

// Vtype
struct _jc_java_security_AllPermission$vtype {
	_jc_type			type;
	_jc_java_security_AllPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AllPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AllPermission$refs {
    _jc_java_security_AllPermission$sub_refs	java_security_AllPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AllPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AllPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_AllPermission$sub_nonrefs	java_security_AllPermission;
};

// Object instance structure
struct _jc_java_security_AllPermission$object {
	_jc_java_security_AllPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AllPermission$vtype	*vtype;
	_jc_java_security_AllPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AllPermission$vtype _jc_java_security_AllPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AllPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AllPermission$class_object;

#endif	/* _JC_java_security_AllPermission_H_ */
